detect_shell_in_environment

Function detect_shell_in_environment 

pub fn detect_shell_in_environment(
    environment: &str,
    options: &IsolationOptions,
) -> String
Detect the best available shell in an isolation environment (docker/ssh) Tries shells in order: bash, zsh, sh Returns the shell path to use