Module isolation_log

Module isolation_log 

Logging and utility functions for isolation runners

Structs

LogHeaderParams
Log header parameters

Functions

append_log_file
Append to a log file, creating its parent directory when needed.
create_log_footer
Create log content footer
create_log_header
Create log content header
create_log_path
Create log file path
create_log_path_for_execution
Create stable log file path for a specific execution UUID/session ID.
create_shell_log_footer_snippet
generate_log_filename
Generate unique log filename
get_default_docker_image
Get the default Docker image based on the host operating system Returns an image that matches the current OS as closely as possible:
get_log_dir
Get log directory from environment or use system temp
get_temp_dir
Get a start-command temporary directory for sidecar files.
get_temp_root
Root directory for start-command temporary files.
get_timestamp
Generate timestamp for logging
shell_quote
wrap_command_with_log_footer
write_log_file
Write log file