pub struct IsolationOptions {Show 18 fields
pub session: Option<String>,
pub image: Option<String>,
pub volumes: Vec<String>,
pub mounts: Vec<String>,
pub env: Vec<String>,
pub privileged: bool,
pub network: Option<String>,
pub network_aliases: Vec<String>,
pub endpoint: Option<String>,
pub detached: bool,
pub user: Option<String>,
pub keep_alive: bool,
pub auto_remove_docker_container: bool,
pub always_cleanup_container: bool,
pub keep_container: bool,
pub keep_container_on_fail: bool,
pub shell: String,
pub log_path: Option<PathBuf>,
}Expand description
Options for isolation
Fields
session: Option<String>Session name
image: Option<String>Docker image
volumes: Vec<String>Docker bind mounts/volumes (-v/–volume)
mounts: Vec<String>Docker –mount specs
env: Vec<String>Docker environment variables (-e/–env, KEY=VALUE)
privileged: boolRun docker container in privileged mode
network: Option<String>Docker network name
network_aliases: Vec<String>Docker network-scoped aliases
endpoint: Option<String>SSH endpoint
detached: boolRun in detached mode
user: Option<String>User to run command as
keep_alive: boolKeep environment alive after command exits
auto_remove_docker_container: boolAuto-remove docker container after exit
always_cleanup_container: boolForce docker container cleanup after exit
keep_container: boolKeep docker container filesystem after exit
keep_container_on_fail: boolKeep docker container filesystem when command fails or OOM-kills
shell: StringShell to use in isolation environments: auto, bash, zsh, sh
log_path: Option<PathBuf>Log path where isolation backends should append live output