pub fn create_start_block(options: &StartBlockOptions<'_>) -> StringExpand description
Create a start block for command execution using timeline format
pub fn create_start_block(options: &StartBlockOptions<'_>) -> StringCreate a start block for command execution using timeline format