pub fn get_value_at_level(
distributed: &[Option<String>],
level: usize,
) -> Option<&str>Expand description
Get the value at a specific level from a distributed option.
Returns None if the index is out of bounds or the value at that level is None.