pub fn is_detached_session_alive(record: &ExecutionRecord) -> Option<bool>Expand description
Check if a detached isolation session is still running Returns Some(true) if running, Some(false) if not, None if unable to determine
pub fn is_detached_session_alive(record: &ExecutionRecord) -> Option<bool>Check if a detached isolation session is still running Returns Some(true) if running, Some(false) if not, None if unable to determine