pub fn match_and_substitute(input: &str, rules: &[Rule]) -> SubstitutionResultExpand description
Match input against rules and return the substituted command
pub fn match_and_substitute(input: &str, rules: &[Rule]) -> SubstitutionResultMatch input against rules and return the substituted command