Argument Parser for start-command wrapper options
Supports two syntax patterns:
- $ [wrapper-options] – [command-options]
- $ [wrapper-options] command [command-options]
Wrapper Options:
–isolated, –isolation, -i
Structs
- Parsed
Args - Result of parsing arguments
- Wrapper
Options - Wrapper options parsed from command line
Constants
- VALID_
BACKENDS - Valid isolation backends
- VALID_
OUTPUT_ FORMATS - Valid output formats for query output
- VALID_
SHELLS - Valid shell options for –shell
Functions
- generate_
session_ name - Generate a unique session name
- generate_
uuid - Generate a UUID v4
- get_
effective_ mode - Get the effective mode for isolation Multiplexers default to attached, docker defaults to attached
- has_
isolation - Check if any isolation options are present
- is_
valid_ uuid - Check if a string is a valid UUID v4
- parse_
args - Parse command line arguments into wrapper options and command
- validate_
options - Validate parsed options and apply defaults