pub fn detect_shell_in_environment(
environment: &str,
options: &IsolationOptions,
) -> StringExpand description
Detect the best available shell in an isolation environment (docker/ssh) Tries shells in order: bash, zsh, sh Returns the shell path to use