pub fn create_virtual_command_block(command: &str) -> StringExpand description
Create a virtual command block for setup steps (like docker pull) Virtual commands are displayed separately in the timeline to show intermediate steps that the tool performs automatically