pub struct StartBlockOptions<'a> {
pub session_id: &'a str,
pub timestamp: &'a str,
pub command: &'a str,
pub extra_lines: Option<Vec<&'a str>>,
pub style: Option<&'a str>,
pub width: Option<usize>,
pub defer_command: bool,
}Expand description
Options for creating a start block
Fields
session_id: &'a strtimestamp: &'a strcommand: &'a strextra_lines: Option<Vec<&'a str>>style: Option<&'a str>width: Option<usize>defer_command: boolIf true, the command line is omitted from the start block (useful when virtual commands will be shown before the actual command)