Substitution Engine for start-command
Parses .lino files and matches natural language commands to shell commands. Uses Links Notation style patterns with variables like $packageName, $version
Structs
- Process
Options - Options for processing a command
- Rule
- A substitution rule parsed from a .lino file
- Substitution
Result - Result of matching and substituting a command
Functions
- create_
rule - Create a rule object from pattern and replacement strings
- load_
default_ substitutions - Load default substitutions from the package’s substitutions.lino file
- load_
user_ substitutions - Load user substitutions from custom path or home directory
- match_
and_ substitute - Match input against rules and return the substituted command
- parse_
lino_ content - Parse .lino content string
- parse_
lino_ file - Parse a .lino substitutions file
- process_
command - Process a command through the substitution engine
- sort_
rules_ by_ specificity - Sort rules so more specific patterns (more variables, longer patterns) match first